==> haskell-hls-explicit-imports-plugin-2.0.0.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-6tYu5TLqXUkFuYhFxXaZUj
key:                  hls-explicit-imports-plugin-2.0.0.0-6tYu5TLqXUkFuYhFxXaZUj
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b2123b7939093feb03fd9c8c46b79043
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.0.0.0-6tYu5TLqXUkFuYhFxXaZUj

depends:
    aeson-2.1.2.1-HgTvGelKFeMCs4MoB4HQQ3 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-6ABiBLao5h014kEH3ydD13
    hls-graph-2.0.0.0-4RbdBH9tIt5AcO4KfLp8ld
    hls-plugin-api-2.0.0.0-1Rv10r62x2d9mEvp4VcVf
    lsp-1.6.0.0-2Oo5MtTAGo3LW7rZdOErf text-2.0.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-imports-plugin-2.0.0.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-LNgMLQ91ZDs4CQCrjXP07Q
key:                  hls-explicit-imports-plugin-2.0.0.0-LNgMLQ91ZDs4CQCrjXP07Q
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  cb20f425028c7e6aa7dbbdbed10699e2
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.0.0.0-LNgMLQ91ZDs4CQCrjXP07Q

depends:
    aeson-2.1.2.1-Kzzie09M6AYFH8VDx0mx86 base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-HhfN95i5olV1pc7AjSOGut
    hls-graph-2.0.0.0-tS20IZqS3eJG8KWrs8FKl
    hls-plugin-api-2.0.0.0-FAIeqCBT2eqIcXKHXT4ELC
    lsp-1.6.0.0-ILXvXfUSiTJ29uGakQXc7N text-2.0.2
    unordered-containers-0.2.20-6lPJVAOvNaZ2RxvZwsH66g

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
